import { isDocAuth } from './auth';
/**
 * AccountBase implements common parts of the IAccount interface.
 */
export class AccountBase {
    prefix;
    auth;
    isPublicKeyCompressed;
    address;
    constructor(prefix, auth, isPublicKeyCompressed = true) {
        this.prefix = prefix;
        this.auth = auth;
        this.isPublicKeyCompressed = isPublicKeyCompressed;
        this.address = this.getAddress();
    }
    get publicKey() {
        return this.auth.getPublicKey(this.isPublicKeyCompressed);
    }
    getAddress() {
        if (isDocAuth(this.auth)) {
            return this.auth.address;
        }
        else {
            return this.getAddressByPubKey();
        }
    }
    toAccountData() {
        return {
            address: this.address,
            algo: this.auth.algo,
            pubkey: this.publicKey.value,
        };
    }
}
