/**
 * Interface representing a Hierarchical Deterministic (HD) path.
 */
export interface IHDPath {
    /**
     * The master path of the HD path (e.g., "m").
     */
    masterPath: string;
    /**
     * The purpose of the HD path (e.g., 44).
     */
    purpose: string;
    /**
     * The coin type of the HD path (e.g., 118).
     */
    coinType: string;
    /**
     * The account index of the HD path (e.g., 0).
     */
    accountIndex: number;
    /**
     * The change index of the HD path (e.g., 0).
     */
    change: number;
    /**
     * the address index of the HD path (e.g., 0).
     */
    addressIndex: number;
    /**
     * The string representation of the HD path (e.g., "m/44'/118'/0'/0/0").
     */
    toString(): string;
}
/**
 * HDPath represents a Hierarchical Deterministic (HD) path.
 */
export declare class HDPath implements IHDPath {
    constructor(coinType: string, accountIndex?: number, change?: number, addressIndex?: number, masterPath?: string, purpose?: string);
    static readonly MASTER_PATH = "m";
    static readonly PURPOSE = "44";
    static readonly COSMOS_COIN_TYPE = "118";
    static readonly ETH_COIN_TYPE = "60";
    /**
     * Derives a HD path for Cosmos.
     */
    static cosmos(accountIndex?: number, change?: number, addressIndex?: number): HDPath;
    /**
     * Derives a HD path for Ethereum.
     */
    static eth(accountIndex?: number, change?: number, addressIndex?: number): HDPath;
    /**
     * The master path of the HD path (e.g., "m").
     */
    masterPath: string;
    /**
     * The purpose of the HD path (e.g., 44).
     */
    purpose: string;
    /**
     * The coin type of the HD path (e.g., 118).
     */
    coinType: string;
    /**
     * The account index of the HD path (e.g., 0).
     */
    accountIndex: number;
    /**
     * The change index of the HD path (e.g., 0).
     */
    change: number;
    /**
     * the address index of the HD path (e.g., 0).
     */
    addressIndex: number;
    /**
     * The string representation of the HD path (e.g., "m/44'/118'/0'/0/0").
     */
    toString(): string;
    /**
     * Derives from a HD path string.
     */
    static fromString(path: string): HDPath;
}
