"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HDPath = void 0;
/**
 * HDPath represents a Hierarchical Deterministic (HD) path.
 */
class HDPath {
    constructor(coinType, accountIndex = 0, change = 0, addressIndex = 0, masterPath = HDPath.MASTER_PATH, purpose = HDPath.PURPOSE) {
        this.masterPath = masterPath;
        this.purpose = purpose;
        this.coinType = coinType;
        this.accountIndex = accountIndex;
        this.change = change;
        this.addressIndex = addressIndex;
    }
    static MASTER_PATH = 'm';
    static PURPOSE = '44';
    // coin types constants
    static COSMOS_COIN_TYPE = '118';
    static ETH_COIN_TYPE = '60';
    // static derivation methods
    /**
     * Derives a HD path for Cosmos.
     */
    static cosmos(accountIndex = 0, change = 0, addressIndex = 0) {
        return new HDPath(HDPath.COSMOS_COIN_TYPE, accountIndex, change, addressIndex);
    }
    /**
     * Derives a HD path for Ethereum.
     */
    static eth(accountIndex = 0, change = 0, addressIndex = 0) {
        return new HDPath(HDPath.ETH_COIN_TYPE, accountIndex, change, addressIndex);
    }
    /**
     * The master path of the HD path (e.g., "m").
     */
    masterPath;
    /**
     * The purpose of the HD path (e.g., 44).
     */
    purpose;
    /**
     * The coin type of the HD path (e.g., 118).
     */
    coinType;
    /**
     * The account index of the HD path (e.g., 0).
     */
    accountIndex;
    /**
     * The change index of the HD path (e.g., 0).
     */
    change;
    /**
     * the address index of the HD path (e.g., 0).
     */
    addressIndex;
    /**
     * The string representation of the HD path (e.g., "m/44'/118'/0'/0/0").
     */
    toString() {
        return `${this.masterPath}/${this.purpose}'/${this.coinType}'/${this.accountIndex}'/${this.change}/${this.addressIndex}`;
    }
    /**
     * Derives from a HD path string.
     */
    static fromString(path) {
        const parts = path.split('/');
        if (parts.length !== 6) {
            throw new Error('Invalid HD path');
        }
        return new HDPath(parts[2].replace("'", ''), parseInt(parts[3].replace("'", ''), 10), parseInt(parts[4], 10), parseInt(parts[5], 10), parts[0], parts[1].replace("'", ''));
    }
}
exports.HDPath = HDPath;
