"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SIGN_MODE = exports.BaseSigner = void 0;
exports.isHttpEndpoint = isHttpEndpoint;
const auth_1 = require("./auth");
function isHttpEndpoint(endpoint) {
    return (typeof endpoint.url === 'string' &&
        typeof endpoint.headers === 'object');
}
/**
 * BaseSigner is a base class for signers
 */
class BaseSigner {
    _auth;
    _config;
    constructor(auth, config) {
        this._auth = auth;
        this._config = config;
    }
    get auth() {
        return this._auth;
    }
    get config() {
        return this._config;
    }
    get publicKey() {
        return this.auth.getPublicKey(this.config.publicKey.isCompressed);
    }
    setAuth(auth) {
        this._auth = auth;
    }
    /**
     * default common implementation for sign arbitrary data in bytes.
     */
    signArbitrary(data) {
        if (!(0, auth_1.isByteAuth)(this.auth)) {
            throw new Error('signArbitrary needs ByteAuth implementation');
        }
        const hashedData = this.config.message.hash(data);
        const signature = this.auth.sign(hashedData);
        return signature.toCompact();
    }
}
exports.BaseSigner = BaseSigner;
/**
 * SIGN_MODE for IGenericOfflineSigner
 */
exports.SIGN_MODE = {
    /**
     * SIGN_MODE for (cosmos_)direct
     */
    DIRECT: 'direct',
    /**
     * SIGN_MODE for (cosmos_)amino
     */
    AMINO: 'amino',
    /**
     * SIGN_MODE for ethereum_tx
     */
    ETHEREUM_TX: 'ethereum_tx',
};
